@@ -14,8 +14,19 @@ class CursorCommands(Commands):
     @command('cursor.right')
     @norerun
     def right(self, wnd):
+        if wnd.screen.selection.has_mark():
+            wnd.cursor.right()
+        elif wnd.screen.selection.is_selected():
+            range = wnd.screen.selection.get_selrange()
+            if wnd.cursor.pos >= range[1]:
+                wnd.cursor.right()
+            else:
+                wnd.cursor.setpos(wnd.cursor.adjust_nextpos(
+                                    wnd.cursor.pos, range[1]))
+        else:
+            wnd.cursor.right()
+            
         wnd.screen.selection.end_cursor()
-        wnd.cursor.right()
         wnd.screen.selection.set_to(wnd.cursor.pos)
 
     @command('cursor.right.select')
@@ -28,10 +39,22 @@ class CursorCommands(Commands):
     @command('cursor.left')
     @norerun
     def left(self, wnd):
+        if wnd.screen.selection.has_mark():
+            wnd.cursor.left()
+        elif wnd.screen.selection.is_selected():
+            range = wnd.screen.selection.get_selrange()
+            if wnd.cursor.pos <= range[0]:
+                wnd.cursor.left()
+            else:
+                wnd.cursor.setpos(wnd.cursor.adjust_nextpos(
+                                    wnd.cursor.pos, range[0]))
+        else:
+            wnd.cursor.left()
+            
         wnd.screen.selection.end_cursor()
-        wnd.cursor.left()
         wnd.screen.selection.set_to(wnd.cursor.pos)
 
+
     @command('cursor.left.select')
     @norerun
     def left_select(self, wnd):
@@ -301,12 +324,13 @@ class ScreenCommands(Commands):
     @command('selection.curword')
     @norerun
     def select_cur_word(self, wnd):
-        f, t = wnd.document.mode.get_word_at(wnd.cursor.pos)
+        ret = wnd.document.mode.get_word_at(wnd.cursor.pos)
+        if ret:
+            f, t, cg = ret
+            f = wnd.cursor.adjust_nextpos(wnd.cursor.pos, f)
+            t = wnd.cursor.adjust_nextpos(wnd.cursor.pos, t)
 
-        f = wnd.cursor.adjust_nextpos(wnd.cursor.pos, f)
-        t = wnd.cursor.adjust_nextpos(wnd.cursor.pos, t)
-
-        wnd.screen.selection.set_range(f, t)
+            wnd.screen.selection.set_range(f, t)
 
     @command('selection.expand-sel')
     @norerun
@@ -794,6 +818,12 @@ class EditCommands(Commands):
             self.put_string(wnd, pyjf3.tofull(s))
             wnd.screen.selection.clear()
 
+    @command('edit.word-complete')
+    @norec
+    @norerun
+    def complete(self, wnd):
+        from kaa.ui.wordcomplete import wordcompletemode
+        wordcompletemode.show_wordlist(wnd)
 
 class CodeCommands(Commands):
     @command('code.region.linecomment')
