@@ -247,6 +247,11 @@ class TextEditorWindow(Window):
                 self.add_str(letters, attr)
                 s += slen
 
+            if row.chars == '\n':
+                if selfrom <= row.posfrom < selto:
+                    if not rectangular or (colfrom == 0):
+                        self.add_str(' ', curses.A_REVERSE)
+            
             self._drawn_rows[row] = (n, cur_sel)
 
         if len(rows) < h:
@@ -300,6 +305,11 @@ class TextEditorWindow(Window):
         self.document.mode.on_cursor_located(self, retpos, y, x)
         return retpos, y, x
 
+    def get_cursor_loc(self):
+        y, x = self._cwnd.getyx()
+        u, l = self._cwnd.getbegyx()
+        return u+y, x+l
+        
     def linedown(self):
         if self.screen.linedown():
             self.draw_screen()
