@@ -8,10 +8,6 @@ from kaa.keyboard import *
 FrameListThemes = {
     'default':
         Theme([
-            Style('default', 'default', 'Blue'),
-            Style('caption', 'red', 'Blue'),
-            Style('activemark', 'default', 'red', nowrap=True),
-            Style('nonactivemark', 'default', 'Blue', nowrap=True),
         ])
 }
 
