@@ -8,12 +8,11 @@ from kaa.ui.dialog import dialogmode
 MsgBoxThemes = {
     'default':
         Theme([
-            Style('default', 'default', 'Magenta'),
-            Style('underline', 'default', 'Magenta', underline=True),
-            Style('caption', 'white', 'Red'),
-            Style('button', 'default', 'magenta', nowrap=True),
-            Style('button.shortcut', 'yellow', 'magenta', underline=True,
-                  bold=True, nowrap=True),
+            Style('underline', 'Base3', 'Base02', underline=True),
+            Style('separator', 'Menu1', 'Base02', nowrap=True),
+            Style('button', 'Menu1', 'Base02', nowrap=True),
+            Style('button.shortcut', 'Menu1', 'Base02', underline=True,
+                   bold=True, nowrap=True),
         ])
 }
 
@@ -102,7 +101,7 @@ class MsgBoxMode(dialogmode.DialogMode):
                           shortcut_style='button.shortcut')
 
             if n < len(options)-1:
-                f.append_text('default', cls.SEPARATOR)
+                f.append_text('separator', cls.SEPARATOR)
 
         f.append_text('default', ' ')
         f.append_text('underline', ' ')
