@@ -1,6 +1,8 @@
 import collections
 from kaa import document
 from kaa.ui.dialog import dialogmode
+from kaa.keyboard import *
+from kaa.command import command, norec, norerun
 
 
 SelectItem = collections.namedtuple(
@@ -23,9 +25,6 @@ class SelectItemList(dialogmode.DialogMode):
 
         return doc
 
-    def init_keybind(self):
-        pass
-
     def get_cursor_visibility(self):
         return 0   # hide cursor
 
@@ -61,7 +60,7 @@ class SelectItemList(dialogmode.DialogMode):
             return
 
         if activate:
-            style = item.style+'-active'
+            style = item.activestyle
         else:
             style = item.style
 
@@ -122,3 +121,4 @@ class SelectItemList(dialogmode.DialogMode):
 
         self.update_sel(wnd, newsel, bottom=bottom)
         return newsel
+
