@@ -1,5 +1,5 @@
-import sys
-KAA_VERSION = (0, 5, 0)
+import sys, os
+KAA_VERSION = (0, 6, 0)
 
 def version_info():
     return '''\
@@ -9,8 +9,10 @@ All Rights Reserved.
 
 Python version: {python_version}
 Platform: {platform}
+$TERM: {term}
 '''.format(
     major=KAA_VERSION[0], minor=KAA_VERSION[1],
     micro=KAA_VERSION[2],
     python_version=sys.version,
-    platform=sys.platform)
+    platform=sys.platform,
+    term=repr(os.environ.get('TERM', ''))[1:-1])
